@@ -70,3 +70,11 @@ def drop_na(features: pd.DataFrame, targets: pd.DataFrame):
 
     features, targets, all = align_features_and_targets(features=features, targets=targets)
     return features, targets, all
+
+
+def add_ohlc(data: pd.DataFrame, ohlc: pd.DataFrame):
+    ohlc_cols = ["Open", "High", "Low", "Close"]
+    remove_ohlc_columns_if_exists(data=data)
+    result = combine_features(features_list=[ohlc, data])
+
+    return result
